@@ -107,6 +107,7 @@ use Chj::TEST;
 use FP::Div qw(min);
 use FP::Ops 'add';
 use FP::Equal 'equal';
+use Scalar::Util qw(blessed);
 
 sub array { [@_] }
 
@@ -257,7 +258,12 @@ sub array_sub {
     my ($a, $from, $to) = @_;    # incl $from, excl $to
     (0 <= $from and $from <= @$a) or die "from out of range: $from";
     (0 <= $to   and $to <= @$a)   or die "to out of range: $to";
-    bless [@$a[$from .. $to - 1]], ref $a
+    my $a2 = [@$a[$from .. $to - 1]];
+    if (defined(my $pck = blessed $a)) {
+        bless $a2, $pck
+    } else {
+        $a2
+    }
 }
 
 sub array_take {
